@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-02-26'; # DATE
-our $VERSION = '1.46'; # VERSION
+our $DATE = '2015-03-10'; # DATE
+our $VERSION = '1.47'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -494,8 +494,7 @@ sub hook_format_result {
         $format = 'text';
     }
 
-    $res->[3]{result_format_options} = $r->{format_options}
-        if $r->{format_options};
+    $res->[3]{format_options} = $r->{format_options} if $r->{format_options};
 
     if ($res->[3]{is_stream}) {
         $log->tracef("Result is a stream");
@@ -745,7 +744,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.46 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-02-26.
+This document describes version 1.47 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-03-10.
 
 =head1 SYNOPSIS
 
